@@ -70,6 +70,8 @@ from lino.core.dbutils import get_field
 from lino.core.dbutils import resolve_field
 #~ from lino.core.dbutils import range_filter
 from lino.core import actions
+from lino.core.constants import _handle_attr_name
+
 from lino.utils.choosers import chooser
 from lino.utils import mti
 from lino.mixins.printable import DirectPrintAction, Printable
@@ -483,7 +485,7 @@ class Budgets(dd.Table):
     window_size=(50,'auto'))
     
     @dd.constant()
-    def spacer(self,ui):  return '<br/>'
+    def spacer(self):  return '<br/>'
 
 
 class MyBudgets(Budgets,mixins.ByUser):
@@ -659,6 +661,10 @@ Wenn hier ein Betrag steht, darf "Verteilen" nicht angekreuzt sein.
         #~ print '20120918 account_choices', account_type
         return accounts.Account.objects.filter(type=account_type)
         
+    #~ @chooser(simple_values=True)
+    #~ def amount_choices(cls,account):
+        #~ return [decimal.Decimal("0"),decimal.Decimal("2.34"),decimal.Decimal("12.34")]
+        
     @chooser()
     def actor_choices(cls,budget):
         return Actor.objects.filter(budget=budget).order_by('seqno')
@@ -805,7 +811,7 @@ class PrintEntriesByBudget(dd.VirtualTable):
             
     @classmethod
     def get_handle_name(self,ar):
-        hname = ar.ui._handle_attr_name
+        hname = _handle_attr_name
         if ar.master_instance is not None:
             #~ hname = super(PrintEntriesByBudget,self).get_handle_name(ar)
             hname += str(len(ar.master_instance.get_actors()))
@@ -1212,6 +1218,9 @@ dd.add_user_group('debts',MODULE_LABEL)
 
 
 def customize_accounts():
+    """
+    Injects a list of fields to the accounts.Account model
+    """
     dd.inject_field(accounts.Account,
         'required_for_household',
         models.BooleanField(
